@@ -19,10 +19,9 @@ import datetime
 from oslo_config import cfg
 from oslo_log import log
 from oslo_utils import timeutils
-import retrying
 import six.moves.urllib.parse as urlparse
 from stevedore import driver
-import warnings
+import tenacity
 
 _NAMESPACE = 'aodh.storage'
 
@@ -35,11 +34,6 @@ OPTS = [
                default=-1,
                help=("Number of seconds that alarm histories are kept "
                      "in the database for (<= 0 means forever).")),
-    cfg.StrOpt('alarm_connection',
-               secret=True,
-               deprecated_for_removal=True,
-               help='The connection string used to connect '
-               'to the alarm database - rather use ${database.connection}'),
 ]
 
 
@@ -47,26 +41,30 @@ class StorageBadVersion(Exception):
     """Error raised when the storage backend version is not good enough."""
 
 
+class AlarmNotFound(Exception):
+    """Error raised when the needed resource not found."""
+
+    def __init__(self, alarm_id):
+        self.alarm_id = alarm_id
+        super(AlarmNotFound, self).__init__("Alarm %s not found" % alarm_id)
+
+
+class InvalidMarker(Exception):
+    """Invalid pagination marker parameters"""
+
+
 def get_connection_from_config(conf):
     retries = conf.database.max_retries
-    if conf.database.alarm_connection is None:
-        url = conf.database.connection
-    else:
-        url = conf.database.alarm_connection
+    url = conf.database.connection
     connection_scheme = urlparse.urlparse(url).scheme
-    if connection_scheme not in ('mysql', 'mysql+pymysql', 'postgresql',
-                                 'sqlite'):
-        msg = ('Storage backend %s is deprecated, and all the NoSQL backends '
-               'will be removed in Aodh 4.0, please use SQL backend.' %
-               connection_scheme)
-        warnings.warn(msg)
     LOG.debug('looking for %(name)r driver in %(namespace)r',
               {'name': connection_scheme, 'namespace': _NAMESPACE})
     mgr = driver.DriverManager(_NAMESPACE, connection_scheme)
 
-    # Convert retry_interval secs to msecs for retry decorator
-    @retrying.retry(wait_fixed=conf.database.retry_interval * 1000,
-                    stop_max_attempt_number=retries if retries >= 0 else None)
+    @tenacity.retry(
+        wait=tenacity.wait_fixed(conf.database.retry_interval),
+        stop=tenacity.stop_after_attempt(retries if retries >= 0 else 5),
+        reraise=True)
     def _get_connection():
         """Return an open connection to the database."""
         return mgr.driver(conf, url)
