@@ -1,5 +1,10 @@
 #!/bin/bash -x
 set -e
+
+export OS_TEST_PATH=aodh/tests/unit
+./tools/pretty_tox.sh $*
+
+export OS_TEST_PATH=aodh/tests/functional
 AODH_TEST_DRIVERS=${AODH_TEST_DRIVERS:-postgresql}
 for indexer in ${AODH_TEST_DRIVERS}
 do
